ptf.macro.thetaSMi <- function(# bla bla bla bla
### bla bla bla (i
 clay 
### Vector of numericals. Clay content [%] of each soil layer / 
### horizon. 
##seealso<<\code{\link{ptf.macro.prefFlow}}, 
## \code{\link{ptf.macro}}.
##references<<Jarvis N., Lindahl, A., Messing, I., Stenemo, F., 
## Hollis, J., Reichenberger, S. & Dubus, I.G., 2007. Algorithm 
## to completely parameterise MACRO from basic soil property data. 
## Report DL21 of the FP6 EU-funded FOOTPRINT project 
## [www.eu-footprint.org], 18p.
## 
## Wosten J.H.M., Lilly A., Nemes A., 
## Le Bas C., 1999. Development and use of a database of hydraulic 
## properties of European soils. Geoderma 90:169-185.
){
  return( "Hello world" ) 
### The function returns a vector of thetaSMi values of the same 
### length as the vector of value provided to each parameter. 
### Unit of thetaSMi is [-] or [m3 of water.m-3 of bulk soil].
}

ptf.macro.prefFlow <- function
### foo
(
 ){}

ptf.macro <- function
### bar
(){
}

.result <- 
 list(ptf.macro = list(definition = "ptf.macro <- function\n### bar\n(){\n}",  
     description = "bar", format = "", title = "ptf macro"), ptf.macro.prefFlow = list( 
     definition = "ptf.macro.prefFlow <- function\n### foo\n(\n ){}",  
     description = "foo", format = "", title = "ptf macro prefFlow"),  
     ptf.macro.thetaSMi = list(definition = "ptf.macro.thetaSMi <- function(# bla bla bla bla\n### bla bla bla (i\n clay \n### Vector of numericals. Clay content [%] of each soil layer / \n### horizon. \n##seealso<<\\code{\\link{ptf.macro.prefFlow}}, \n## \\code{\\link{ptf.macro}}.\n##references<<Jarvis N., Lindahl, A., Messing, I., Stenemo, F., \n## Hollis, J., Reichenberger, S. & Dubus, I.G., 2007. Algorithm \n## to completely parameterise MACRO from basic soil property data. \n## Report DL21 of the FP6 EU-funded FOOTPRINT project \n## [www.eu-footprint.org], 18p.\n## \n## Wosten J.H.M., Lilly A., Nemes A., \n## Le Bas C., 1999. Development and use of a database of hydraulic \n## properties of European soils. Geoderma 90:169-185.\n){\n  return( \"Hello world\" ) \n### The function returns a vector of thetaSMi values of the same \n### length as the vector of value provided to each parameter. \n### Unit of thetaSMi is [-] or [m3 of water.m-3 of bulk soil].\n}",  
         description = "bla bla bla (i", `item{clay}` = "Vector of numericals. Clay content [%] of each soil layer / \nhorizon. ",  
         value = "The function returns a vector of thetaSMi values of the same \nlength as the vector of value provided to each parameter. \nUnit of thetaSMi is [-] or [m3 of water.m-3 of bulk soil].",  
         seealso = "\\code{\\link{ptf.macro.prefFlow}}, \n\\code{\\link{ptf.macro}}.",  
         references = "Jarvis N., Lindahl, A., Messing, I., Stenemo, F., \nHollis, J., Reichenberger, S. & Dubus, I.G., 2007. Algorithm \nto completely parameterise MACRO from basic soil property data. \nReport DL21 of the FP6 EU-funded FOOTPRINT project \n[www.eu-footprint.org], 18p.\n\nWosten J.H.M., Lilly A., Nemes A., \nLe Bas C., 1999. Development and use of a database of hydraulic \nproperties of European soils. Geoderma 90:169-185.",  
         title = "bla bla bla bla", format = "")) 
