testFunc<-function(
### Generates a probability plot of probability limits from simulated data, including optional comparison with observed data
leg.txt=c("Obs","50% PL","90% PL") ##<< vector of legend text, default= \code{c("Obs","Sim. Median","Sim. 90% PL")}
){
return(leg.txt)  
}
.result <- 
 list(testFunc = list(definition = "testFunc<-function(\n### Generates a probability plot of probability limits from simulated data, including optional comparison with observed data\nleg.txt=c(\"Obs\",\"50% PL\",\"90% PL\") ##<< vector of legend text, default= \\code{c(\"Obs\",\"Sim. Median\",\"Sim. 90% PL\")}\n){\nreturn(leg.txt)  \n}",  
     description = "Generates a probability plot of probability limits from simulated data, including optional comparison with observed data",  
     `item{leg.txt}` = "vector of legend text, default= \\code{c(\"Obs\",\"Sim. Median\",\"Sim. 90% PL\")}",  
     format = "", title = "testFunc")) 
  
