"vectorElements<-" <- function(
		### adds or replaces value in vec
		vec			##<< a named vector
		,value		##<< a named vector of same mode as vec
){
}

.result <- list(
  `vectorElements<-` = list(
    description = "adds or replaces \\code{value} in \\code{vec}",
    `item{vec}` = "a named vector",
    `item{value}` = "a named vector of same mode as \\code{vec}",
    format = "",
    title = "vectorElements<-"))
